@@ -34,9 +34,10 @@ class DBusMenuImporterTest : public QObject
 Q_OBJECT
 private Q_SLOTS:
     void testStandardItem();
-
-    void init();
-    void cleanup();
+    void testAddingNewItem();
+    void testShortcut();
+    void testDeletingImporterWhileWaitingForAboutToShow();
+    void testDynamicMenu();
 };
 
 #endif /* DBUSMENUIMPORTERTEST_H */
